@@ -8,31 +8,23 @@
 # @Software     : PyCharm
 # @Description  : 
 
-import time
-import uvicorn
+from meutils.pipe import *
 
-from datetime import datetime
-from typing import Optional
-from fastapi import FastAPI, Form, Depends, File, UploadFile
-from pydantic import BaseModel
-from starlette.staticfiles import StaticFiles
-from starlette.requests import Request
-from starlette.responses import \
-    RedirectResponse, FileResponse, HTMLResponse, PlainTextResponse
 from starlette.status import *
+from starlette.responses import *
+from starlette.requests import Request
+from starlette.staticfiles import StaticFiles
 
-from collections import OrderedDict
-from traceback import format_exc  # https://www.cnblogs.com/klchang/p/4635040.html
+from fastapi import FastAPI, Form, Depends, File, UploadFile
 
 
 class App(object):
-    """
-    TODO: 把函数response封装好，支持多个app-run
-    """
 
     def __init__(self, verbose=True):
         self.app = FastAPI()
         self.verbose = verbose
+        self.get = self.app.get
+        self.post = self.app.post
 
     def run(self, app=None, host="0.0.0.0", port=8000, workers=1, access_log=True, debug=False, reload=False, **kwargs):
         """
@@ -47,6 +39,8 @@ class App(object):
         :param kwargs:
         :return:
         """
+        import uvicorn
+
         uvicorn.run(
             app if app else self.app,
             host=host, port=port, workers=workers, access_log=access_log, debug=debug, reload=reload, **kwargs
@@ -57,7 +51,23 @@ class App(object):
         handler = self._handler(func, method, **kwargs)
         self.app.api_route(path=path, methods=[method])(handler)
 
-    def _handler(self, func, method='GET', result_key='Result', **kwargs):
+    def add_apps(self, app_dir='apps', **kwargs):
+        """加载当前app_dir文件夹下的所有app, 入口函数都是main"""
+        routes = []
+        for p in Path(app_dir).rglob('*.py'):
+            if not p.stem.startswith('_'):  # 过滤_开头的py
+                route = str(p)[:-3]
+                func = importlib.import_module(route.replace('/', '.')).main
+                self.add_route(route, func, method='POST', **kwargs)
+
+                routes.append(route)
+
+        logger.info(f"Add Routes: {routes}")
+
+        self.add_route(f'/__{app_dir}', lambda: routes, method='GET', **kwargs)
+        return routes
+
+    def _handler(self, func, method='GET', result_key='data', **kwargs):
         """
 
         :param func:
@@ -83,34 +93,29 @@ class App(object):
 
         return handler
 
-    def _try_func(self, kwargs, func, result_key='Result', **kwargs_):
+    def _try_func(self, kwargs, func, result_key='data', **kwargs_):
         input = kwargs
         output = OrderedDict()
 
         if self.verbose:
-            output['RequestParams'] = input
+            output['requestParams'] = input
 
         try:
-            output['Success'] = 1
+            output['success'] = 1
             output[result_key] = func(**input)
 
         except Exception as error:
-            output['Success'] = 0
-            output['Error'] = error
-            output['ErrorPlus'] = format_exc().strip()
+            output['success'] = 0
+            output['error'] = error
+            output['errorPlus'] = traceback.format_exc().strip()
 
         finally:
             output.update(kwargs_)
 
         return output
 
-    def app_file_name(self, file):
-        """
-        file = __file__
-        """
-        print(file)
-        _ = file.split('/')[-1].split('.')[0]
-        return f"{_}:app"
+    def app_file_name(self, file=__file__):
+        return Path(file).stem
 
 
 if __name__ == '__main__':
@@ -120,5 +125,5 @@ if __name__ == '__main__':
     app.add_route('/get', lambda **kwargs: kwargs, method="GET", result_key="GetResult")
     app.add_route('/post', lambda **kwargs: kwargs, method="POST", result_key="PostResult")
 
-    app.run(port=9000, debug=False, reload=False)
+    # app.run(port=9000, debug=False, reload=False, access_log=True)
     # app.run(f"{app.app_file_name(__file__)}", port=9000, debug=False, reload=False)
