@@ -24,25 +24,29 @@ from starlette.status import *
 app = FastAPI()
 
 
-@app.post('/')
-def read_root(kwargs:dict, a:int=0):
+@app.post('/post/{p}')
+def read_root(kwargs: dict, p: str, a: int = 0):
     print(kwargs)
     print(type(a), a)
+    print(p)
     return kwargs
 
+
 @app.post('/')
-def read_root(kwargs:dict):
+def read_root(kwargs: dict):
     print(kwargs)
     return kwargs
 
+
 @app.get('/xx/{xx}')
-def get(request: Request, xx):
+def get(request: Request, xx, kwargs: dict):
+    print(kwargs)
     kwargs = dict(request.query_params)
+    print(kwargs)
     print(f"xx: {xx.split(',')}")
     return kwargs
 
 
-
 if __name__ == '__main__':
     import uvicorn
 
